@@ -10,15 +10,15 @@ use std::collections::HashSet;
 /// [ParserColumn] is exposed so you can use its type and traits
 /// but normally you create a [ParserColumn]
 /// by using [earley](crate::parser::earley).
-pub struct ParserColumn<Value> {
+pub struct ParserColumn<AST> {
     pub(crate) index:  usize,
     pub(crate) kind:   String,
-    pub(crate) states: Vec<ParserState<Value>>,
+    pub(crate) states: Vec<ParserState<AST>>,
     pub(crate) unique: HashSet<u64>,
 }
 
-impl<Value> ParserColumn<Value> {
-    pub(crate) fn add(&mut self, state: ParserState<Value>) {
+impl<AST> ParserColumn<AST> {
+    pub(crate) fn add(&mut self, state: ParserState<AST>) {
         let mut state = state;
         let digest = state.hash_me();
 
@@ -30,7 +30,7 @@ impl<Value> ParserColumn<Value> {
     }
 }
 
-impl<Value> std::fmt::Display for ParserColumn<Value> {
+impl<AST> std::fmt::Display for ParserColumn<AST> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(
             f,
